pynrc.nrc\_hci
==============

.. automodule:: pynrc.nrc_hci

   
   
   .. rubric:: Module Attributes

   .. autosummary::
      :toctree:
   
      LONG_WAVELENGTH_MAX
      LONG_WAVELENGTH_MIN
      ND_acq
      SHORT_WAVELENGTH_MAX
      SHORT_WAVELENGTH_MIN
      aperturename
      bandpass
      bar_offset
      channel
      coron_substrate
      det_info
      detector
      detector_list
      detector_position
      fastaxis
      filter
      filter_list
      fov_pix
      image_mask
      is_coron
      is_dark
      is_grism
      is_lyot
      module
      multiaccum
      multiaccum_times
      name
      ndeg
      npsf
      options
      oversample
      pixelscale
      psf_info
      pupil
      pupil_mask
      pupilopd
      quick
      save_dir
      save_name
      scaid
      siaf_ap
      siaf_ap_names
      slowaxis
      telescope
      wave_fit
      well_level
      include_ote_field_dependence
      image_mask_list
      pupil_mask_list
   
   

   
   
   

   
   
   

   
   
   



